<?php

namespace Drupal\home_page_for_roles\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

class HomePageForRolesSettingsForm extends ConfigFormBase {

  protected function getEditableConfigNames() {
    return ['home_page_for_roles.settings'];
  }

  public function getFormId() {
    return 'home_page_for_roles_settings_form';
  }

  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('home_page_for_roles.settings');

    // Default homepage for anonymous users
    $form['anonymous_homepage'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Anonymous Users Homepage'),
      '#description' => $this->t('Enter the path (e.g., /node/1 or /welcome)'),
      '#default_value' => $config->get('anonymous_homepage') ?? '/',
      '#required' => TRUE,
    ];

    // Default homepage for authenticated users
    $form['authenticated_homepage'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Default Authenticated Users Homepage'),
      '#description' => $this->t('Default homepage for logged-in users without specific group settings'),
      '#default_value' => $config->get('authenticated_homepage') ?? '/user',
      '#required' => TRUE,
    ];

    // Get all roles except anonymous and authenticated
    $roles = user_roles(TRUE);
    unset($roles['authenticated']);
    
    $form['role_homepages'] = [
      '#type' => 'fieldset',
      '#title' => $this->t('Role-specific Homepages'),
      '#tree' => TRUE,
    ];

    foreach ($roles as $role_id => $role) {
      $form['role_homepages'][$role_id] = [
        '#type' => 'textfield',
        '#title' => $this->t('@role Homepage', ['@role' => $role->label()]),
        '#description' => $this->t('Homepage for users with the @role role', ['@role' => $role->label()]),
        '#default_value' => $config->get("role_homepages.$role_id"),
      ];
    }

    return parent::buildForm($form, $form_state);
  }

  public function submitForm(array &$form, FormStateInterface $form_state) {
    $config = $this->config('home_page_for_roles.settings');
    
    $config->set('anonymous_homepage', $form_state->getValue('anonymous_homepage'))
           ->set('authenticated_homepage', $form_state->getValue('authenticated_homepage'))
           ->set('role_homepages', $form_state->getValue('role_homepages'))
           ->save();

    parent::submitForm($form, $form_state);
  }
}